<?php

namespace Drupal\proc\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller.
 *
 * @see \Drupal\Core\Form\FormBase
 */
class ProcKeysCacheTypeForm extends FormBase {

  /**
   * Build the form.
   *
   * A build form method constructs an array that defines how markup and
   * other form elements are included in an HTML form.
   *
   * @param array $form
   *   Default form array structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Object containing current form state.
   *
   * @return array
   *   The render array defining the elements of the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Get the latest proc key of the current user:
    $user = \Drupal::currentUser();
    $uid = $user->id();

    $keyring_proc_object = _proc_get_keys($uid);
    $keyring_cache_type = $keyring_proc_object['keyring_type'];

    $form['proc_keys_cache_type'] = [
      '#type' => 'radios',
      '#title' => $this->t('Cache type for your Protected Content key'),
      '#default_value' => $keyring_cache_type ?? '',
      '#options' => [
        'keyring' => $this->t('No cache'),
        'keyring_1h' => $this->t('1 hour cache'),
        'keyring_2h' => $this->t('2 hours cache'),
      ],
    ];
    $form['proc_keys_cache_type_pid'] = [
      '#type' => 'hidden',
      '#default_value' => $keyring_proc_object['keyring_cid'] ?? '',
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    // Add a submit button that handles the submission of the form.
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * Getter method for Form ID.
   *
   * @return string
   *   The unique ID of the form defined by this class.
   */
  public function getFormId() {
    return 'proc_keyring_type_form';
  }

  /**
   * Form submit handler.
   *
   * @param array $form
   *   The render array of the currently built form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Object describing the current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Proc keyring Id for updating:
    $proc_id = $form_state->getValues()['proc_keys_cache_type_pid'];
    // Proc keyring type for updating:
    $keyring_type = $form_state->getValues()['proc_keys_cache_type'];

    // Update the proc keyring entity:
    $keyring = \Drupal::entityTypeManager()->getStorage('proc')->load($proc_id);
    $keyring->set('type', $keyring_type);
    $keyring->save();

    // Set a message that the proc keyring has been updated:
    $this->messenger()->addMessage($this->t('Your Protected Content key cache type has been updated.'));

  }

}
