<?php

namespace Drupal\proc\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceLabelFormatter;

/**
 * Plugin implementation of the 'entity reference label' formatter.
 *
 * @FieldFormatter(
 *   id = "proc_entity_reference_armoured_formatter",
 *   label = @Translation("Armoured"),
 *   description = @Translation("Display the armoured cipher text for decryption on lists."),
 *   field_types = {
 *     "proc_entity_reference_field"
 *   }
 * )
 */
class ProcArmouredFieldFormatter extends EntityReferenceLabelFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      $cipher_text = $entity->getCipherText();
      $label = $entity->label();

      $elements[$delta]['placeholder'] = [
        '#type' => 'inline_template',
        '#context' => [
          'value' => $cipher_text,
          'label' => $label,
          'class' => ['proc-armoured-field-formatter'],
          'pid' => $entity->id(),
        ],
        '#template' => '<div id="proc-list-item-{{ pid }}" class="{{class|join(" ")}}" data-proc-list-item-pid="{{ pid }}" data-proc-list-item-cipher-text="{{ value|raw }}">{{ label }}</div>',
      ];
    }

    $keyring = _proc_get_keys(\Drupal::currentUser()->id(), 'uid');

    $privkey = $keyring['encrypted_private_key'];

    $elements['#attached'] = [
      'library' => [
        0 => 'proc/openpgpjs',
        1 => 'proc/proc-decrypt-list',
      ],
      'drupalSettings' => [
        'proc' => [
          'proc_labels' => _proc_js_labels(),
          'proc_pass' => _proc_common_get_decryption_form_data(NULL)['proc_pass'],
          'proc_privkey' => $privkey,
        ],
      ],
    ];

    return $elements;
  }

}
